@@ -13,38 +13,38 @@ ppm.wine <- as.numeric(Winedata$ppm)
 wine.color <- Winedata$wine.color 
 wine.origin <- Winedata$origin 
 # all spectra
-drawSpecPPM(Y.spec = Spectra.wine, 
-            X.ppm = ppm.wine, 
-            title = 'Wine data spectra', 
-            groupFactor = wine.color, 
-            legend.extra.x = 1, 
-            legend.extra.y = 1.1)
+speaq::drawSpecPPM(Y.spec = Spectra.wine, 
+                   X.ppm = ppm.wine, 
+                   title = 'Wine data spectra', 
+                   groupFactor = wine.color, 
+                   legend.extra.x = 1, 
+                   legend.extra.y = 1.1)
 
 ## ----wine excerpt, dpi=dpi.HQ, fig.width=7, fig.height=4, out.width = figwidth.out----
 # small excerpt by defining the region of interest
-drawSpecPPM(Y.spec = Spectra.wine, 
-            X.ppm = ppm.wine, 
-            groupFactor = as.factor(wine.color), 
-            title = 'Raw wine data excerpt', 
-            legend.extra.x = 1.1, 
-            legend.extra.y = 1.0, 
-            ROI.ppm = 3.6, 
-            ROI = NULL, 
-            roiWidth.ppm = 0.15, 
-            legendpos = "topright" )
+speaq::drawSpecPPM(Y.spec = Spectra.wine, 
+                   X.ppm = ppm.wine, 
+                   groupFactor = as.factor(wine.color), 
+                   title = 'Raw wine data excerpt', 
+                   legend.extra.x = 1.1, 
+                   legend.extra.y = 1.0,
+                   ROI.ppm = 3.6, 
+                   ROI = NULL, 
+                   roiWidth.ppm = 0.15,
+                   legendpos = "topright" )
 
 ## ----detect winepeaks,  results = "hide"---------------------------------
-wine.peaks <- getWaveletPeaks(Y.spec=Spectra.wine, 
-                             X.ppm=ppm.wine, 
-                             baselineThresh = 10,
-                             SNR.Th = -1, 
-                             nCPU = 2, 
-                             include_nearbyPeaks = TRUE) # nCPU set to 2 for the vignette build
+wine.peaks <- speaq::getWaveletPeaks(Y.spec=Spectra.wine, 
+                                     X.ppm=ppm.wine, 
+                                     baselineThresh = 10,
+                                     SNR.Th = -1, 
+                                     nCPU = 2, 
+                                     include_nearbyPeaks = TRUE) # nCPU set to 2 for the vignette build
 
 
-wine.grouped <- PeakGrouper(Y.peaks = wine.peaks,  
-                            min.samp.grp = 5, 
-                            grouping.window.width = 200)
+wine.grouped <- speaq::PeakGrouper(Y.peaks = wine.peaks,  
+                                   min.samp.grp = 5, 
+                                   grouping.window.width = 200)
 
 
 ## ----plots base, dpi=dpi.HQ, fig.width=7, fig.height=10, fig.keep = "last", out.width = figwidth.out, warnings = FALSE----
@@ -53,17 +53,17 @@ library(ggplot2)
 ROI.ppm <- 1.330
 roiWidth.ppm <- 0.025
 
-ROIplot(Y.spec = Spectra.wine, 
-        X.ppm = ppm.wine, 
-        ungrouped.peaks = wine.peaks,
-        grouped.peaks = wine.grouped, 
-        ROI.ppm = ROI.ppm,
-        roiWidth.ppm = roiWidth.ppm , 
-        groupLabels = as.factor(wine.color))
+speaq::ROIplot(Y.spec = Spectra.wine, 
+               X.ppm = ppm.wine, 
+               ungrouped.peaks = wine.peaks,
+               grouped.peaks = wine.grouped, 
+               ROI.ppm = ROI.ppm,
+               roiWidth.ppm = roiWidth.ppm, 
+               groupLabels = as.factor(wine.color))
 
 ## ----silhouette values,  results = "hide", dpi=dpi.LQ, fig.width=6, fig.height=3.5, out.width = 500----
-SilhouetteValues <- SilhouetR(DataMatrix = wine.grouped$peakPPM, 
-                              GroupIndices = wine.grouped$peakIndex)
+SilhouetteValues <- speaq::SilhouetR(DataMatrix = wine.grouped$peakPPM, 
+                                     GroupIndices = wine.grouped$peakIndex)
 
 Silh_plot <- ggplot(SilhouetteValues, aes(SilhouetteValues)) +
              geom_freqpoly(binwidth = 0.03) +
@@ -94,22 +94,22 @@ faulty.groupIndex <- sil_means[1,1]
 ROI.ppm <- ppm.wine[faulty.groupIndex]
 roiWidth.ppm <- 0.1
 
-ROIplot(Y.spec = Spectra.wine, 
-        X.ppm = ppm.wine, 
-        ungrouped.peaks = wine.peaks,
-        grouped.peaks = wine.grouped , 
-        ROI.ppm = ROI.ppm ,
-        roiWidth.ppm = roiWidth.ppm , 
-        groupLabels = as.factor(wine.color))
+speaq::ROIplot(Y.spec = Spectra.wine, 
+               X.ppm = ppm.wine, 
+               ungrouped.peaks = wine.peaks,
+               grouped.peaks = wine.grouped, 
+               ROI.ppm = ROI.ppm,
+               roiWidth.ppm = roiWidth.ppm, 
+               groupLabels = as.factor(wine.color))
 
 
 ## ----regroup-------------------------------------------------------------
 wrong.groups <- sort(sil_means[sil_means[,1]>=sil_means[1,1],1])[1:2]
 
-wine.regrouped <- regroupR(grouped.peaks = wine.grouped, 
-                           list.to.regroup = wrong.groups, 
-                           min.samp.grp = 5 ,
-                           max.dupli.prop = 0.1)
+wine.regrouped <- speaq::regroupR(grouped.peaks = wine.grouped,
+                                  list.to.regroup = wrong.groups, 
+                                  min.samp.grp = 5,
+                                  max.dupli.prop = 0.1)
 
 
 ## ----regroup fix plot,  dpi=dpi.HQ, fig.width=7, fig.height=10, fig.keep = "last", out.width = figwidth.out, warnings = FALSE----
@@ -121,29 +121,29 @@ roiWidth.ppm <- 0.1
 
 
 
-ROIplot(Y.spec = Spectra.wine, 
-        X.ppm = ppm.wine, 
-        ungrouped.peaks = wine.peaks,
-        grouped.peaks = wine.regrouped , 
-        ROI.ppm = ROI.ppm ,
-        roiWidth.ppm = roiWidth.ppm , 
-        groupLabels = as.factor(wine.color))
+speaq::ROIplot(Y.spec = Spectra.wine, 
+               X.ppm = ppm.wine, 
+               ungrouped.peaks = wine.peaks,
+               grouped.peaks = wine.regrouped, 
+               ROI.ppm = ROI.ppm,
+               roiWidth.ppm = roiWidth.ppm, 
+               groupLabels = as.factor(wine.color))
 
 
 
 ## ----data matrix, results = "hide", message=FALSE------------------------
 
-wine.filled <- PeakFilling(Y.grouped = wine.regrouped, 
-                          Y.spec = Spectra.wine,  
-                          max.index.shift = 200,
-                          nCPU = 2) # nCPU set to 1 for the vignette build
+wine.filled <- speaq::PeakFilling(Y.grouped = wine.regrouped, 
+                                  Y.spec = Spectra.wine,  
+                                  max.index.shift = 200,
+                                  nCPU = 2) # nCPU set to 1 for the vignette build
 
-wine.Features <- BuildFeatureMatrix(wine.filled)
+wine.Features <- speaq::BuildFeatureMatrix(wine.filled)
 
 
 ## ----scaling-------------------------------------------------------------
-wine.Features.scaled <- SCANT(data.matrix = wine.Features, 
-                              type = c("pareto", "center"))  
+wine.Features.scaled <- speaq::SCANT(data.matrix = wine.Features, 
+                                     type = c("pareto", "center"))  
 
 
 ## ----PCA, dpi=dpi.LQ, fig.width=7, fig.height=5, out.width = 500---------
@@ -186,16 +186,16 @@ legend("topleft",
 
 
 ## ----no rose-------------------------------------------------------------
-red.white.scaled <- SCANT(wine.Features[wine.color!="rose",], 
-                         type = c("pareto", "center"))  
+red.white.scaled <- speaq::SCANT(wine.Features[wine.color!="rose",], 
+                                 type = c("pareto", "center"))  
 
 red.white.colors <- as.factor(as.character(wine.color)[wine.color!="rose"])
 
 
 ## ----relevant peaks------------------------------------------------------
-p.all_bonf <- relevant.features.p(datamatrix = red.white.scaled,
-                                  responsevector = red.white.colors, 
-                                  p.adj = "bonferroni")
+p.all_bonf <- speaq::relevant.features.p(datamatrix = red.white.scaled,
+                                         responsevector = red.white.colors, 
+                                         p.adj = "bonferroni")
 
 significant.features <- p.all_bonf[p.all_bonf$p.values<=0.05, ]
 
@@ -220,20 +220,21 @@ roiWidth.ppm <- 0.03
 
 
 ggplot(p.all_bonf, aes(x=as.numeric(rownames(p.all_bonf)), y= -log10(p.values) )) + 
-      geom_point(data = p.all_bonf[-interest.peakIndex,],  
-                 aes(x=as.numeric(rownames(p.all_bonf[-interest.peakIndex,])), y= -log10(p.values) ),
-                 shape = 16) +
-      geom_point(data = p.all_bonf[interest.peakIndex,],  aes(x=interest.peakIndex, y= -log10(p.values) ),
-                 shape = 18, 
-                 size = 3, 
-                 colour ="#00B0F6" ) +
-    xlab("feature index") + 
-    ylab("- log10 p-value") + 
-    ggtitle("Bonferroni corrected p-values") +
-    geom_hline(aes(yintercept= -log10(0.05), color="red"),linetype = 2) + guides(color=FALSE)+
-    theme_bw() + 
-    theme(plot.title = element_text(lineheight = 0.8, face="bold", margin = margin(12,0,13,0),hjust = 0.5, size = 15), 
-          text = element_text(size=14))
+       geom_point(data = p.all_bonf[-interest.peakIndex,],  
+                  aes(x=as.numeric(rownames(p.all_bonf[-interest.peakIndex,])), y= -log10(p.values) ),
+                  shape = 16) +
+       geom_point(data = p.all_bonf[interest.peakIndex,],  aes(x=interest.peakIndex, y= -log10(p.values) ),
+                  shape = 18, 
+                  size = 3, 
+                  colour ="#00B0F6" ) +
+       xlab("feature index") + 
+       ylab("- log10 p-value") + 
+       ggtitle("Bonferroni corrected p-values") +
+       geom_hline(aes(yintercept= -log10(0.05), color="red"),linetype = 2) + 
+       guides(color=FALSE) +
+       theme_bw() + 
+       theme(plot.title = element_text(lineheight = 0.8, face="bold", margin = margin(12,0,13,0),hjust = 0.5, size = 15), 
+             text = element_text(size=14))
 
 
 
@@ -245,13 +246,13 @@ ggplot(p.all_bonf, aes(x=as.numeric(rownames(p.all_bonf)), y= -log10(p.values) )
 
 
 
-ROIplot(Y.spec = Spectra.wine, 
-        X.ppm = ppm.wine, 
-        ungrouped.peaks = wine.peaks,
-        grouped.peaks = wine.regrouped , 
-        ROI.ppm = ROI.ppm ,
-        roiWidth.ppm = roiWidth.ppm , 
-        groupLabels = as.factor(wine.color))
+speaq::ROIplot(Y.spec = Spectra.wine,
+               X.ppm = ppm.wine, 
+               ungrouped.peaks = wine.peaks,
+               grouped.peaks = wine.regrouped, 
+               ROI.ppm = ROI.ppm,
+               roiWidth.ppm = roiWidth.ppm, 
+               groupLabels = as.factor(wine.color))
 
 
 
@@ -276,34 +277,34 @@ drawSpecPPM(Y.spec = Spectra.wine[wine.color != "rose", ],
 ## ----speaq 1.0,  dpi=dpi.HQ, fig.width=7, fig.height=4, message=F, out.width = figwidth.out----
 
 
-peakList <- detectSpecPeaks(as.matrix(Spectra.wine),   
-                            nDivRange = 128,                
-                            scales = seq(1, 16, 2),
-                            baselineThresh = 100,
-                            SNR.Th = -1,
-                            verbose=FALSE)
+peakList <- speaq::detectSpecPeaks(as.matrix(Spectra.wine),   
+                                   nDivRange = 128,   
+                                   scales = seq(1, 16, 2),
+                                   baselineThresh = 100,
+                                   SNR.Th = -1,
+                                   verbose=FALSE)
 
 resFindRef <- findRef(peakList)
 refInd <- resFindRef$refInd
 
-aligned.spectra <- dohCluster(as.matrix(Spectra.wine), 
-                              peakList = peakList,
-                              refInd = refInd,
-                              maxShift  = 200,
-                              acceptLostPeak = TRUE, verbose=FALSE)
+aligned.spectra <- speaq::dohCluster(as.matrix(Spectra.wine), 
+                                     peakList = peakList,
+                                     refInd = refInd,
+                                     maxShift  = 200,
+                                     acceptLostPeak = TRUE, verbose=FALSE)
       
                 
-drawSpecPPM(Y.spec = aligned.spectra[wine.color != "rose", ], 
-            X.ppm = ppm.wine, 
-            groupFactor = red.white.colors, 
-            title = paste("significant feature, p-value =",
-                          format(significant.features$p.values[peak_of_interest], 
-                                 scientific = TRUE, 
-                                 digits=2),
-                          sep=" "), 
-            legend.extra.x = 1.1, 
-            legend.extra.y = 0.9,
-            ROI = significant.features$index[peak_of_interest], 
-            roiWidth = 100, 
-            legendpos = "topright" )               
+speaq::drawSpecPPM(Y.spec = aligned.spectra[wine.color != "rose", ], 
+                   X.ppm = ppm.wine, 
+                   groupFactor = red.white.colors, 
+                   title = paste("significant feature, p-value =",
+                                 format(significant.features$p.values[peak_of_interest], 
+                                        scientific = TRUE, 
+                                        digits=2),
+                                 sep=" "), 
+                   legend.extra.x = 1.1, 
+                   legend.extra.y = 0.9,
+                   ROI = significant.features$index[peak_of_interest], 
+                   roiWidth = 100, 
+                   legendpos = "topright" )               
 
